@@ -15,23 +15,22 @@ use clap::{App as ClapApp, Arg};
 use log::{info, warn};
 use std::sync::{Arc, RwLock};
 
-use crate::database::UpEndDatabase;
+use crate::{common::PKG_VERSION, database::UpEndDatabase};
 
 mod addressing;
+mod common;
 mod database;
 mod filesystem;
 mod previews;
 mod routes;
 mod util;
 
-const VERSION: &str = env!("CARGO_PKG_VERSION");
-
 fn main() -> Result<()> {
     let env = env_logger::Env::default().filter_or(env_logger::DEFAULT_FILTER_ENV, "info");
     env_logger::init_from_env(env);
 
     let app = ClapApp::new("upend")
-        .version(VERSION)
+        .version(PKG_VERSION)
         .author("Tomáš Mládek <t@mldk.cz>")
         .arg(Arg::with_name("DIRECTORY").required(true).index(1))
         .arg(
@@ -45,7 +44,7 @@ fn main() -> Result<()> {
             Arg::with_name("DB_PATH")
                 .long("db-path")
                 .takes_value(true)
-                .help("path to sqlite db file (\"$VAULT_PATH/upend.sqlite\" by default)"),
+                .help("path to sqlite db file (\"$VAULT_PATH/.upend\" by default)"),
         )
         .arg(
             Arg::with_name("NO_BROWSER")
@@ -81,7 +80,7 @@ fn main() -> Result<()> {
 
     let matches = app.get_matches();
 
-    info!("Starting UpEnd {}...", VERSION);
+    info!("Starting UpEnd {}...", PKG_VERSION);
     let sys = actix::System::new("upend");
 
     let job_container = Arc::new(RwLock::new(util::jobs::JobContainer::default()));
@@ -157,6 +156,7 @@ fn main() -> Result<()> {
                 .service(routes::get_query)
                 .service(routes::get_object)
                 .service(routes::put_object)
+                .service(routes::put_object_attribute)
                 .service(routes::delete_object)
                 .service(routes::get_all_attributes)
                 .service(routes::api_refresh)
@@ -194,7 +194,7 @@ fn main() -> Result<()> {
 
     if !matches.is_present("NO_INITIAL_UPDATE") {
         info!("Running initial update...");
-        actix::spawn(filesystem::rescan_vault(upend, job_container, true));
+        actix::spawn(filesystem::rescan_vault(upend, job_container, false, true));
     }
 
     #[cfg(feature = "desktop")]
