@@ -1,5 +1,5 @@
 use crate::addressing::{Address, Addressable};
-use crate::database::entry::{Entry, InEntry};
+use crate::database::entry::{Entry, EntryValue, InEntry};
 use crate::database::hierarchies::{list_roots, resolve_path, UHierPath};
 use crate::database::lang::Query;
 use crate::database::UpEndDatabase;
@@ -29,8 +29,6 @@ use tempfile::NamedTempFile;
 #[cfg(feature = "desktop")]
 use is_executable::IsExecutable;
 
-const VERSION: &str = env!("CARGO_PKG_VERSION");
-
 #[derive(Clone)]
 pub struct State {
     pub upend: Arc<UpEndDatabase>,
@@ -275,6 +273,36 @@ pub async fn put_object(
     ))
 }
 
+#[put("/api/obj/{address}/{attribute}")]
+pub async fn put_object_attribute(
+    state: web::Data<State>,
+    web::Path((address, attribute)): web::Path<(Address, String)>,
+    value: web::Json<EntryValue>,
+) -> Result<HttpResponse, Error> {
+    let connection = state.upend.connection().map_err(ErrorInternalServerError)?;
+
+    let new_address = connection
+        .transaction::<_, anyhow::Error, _>(|| {
+            let existing_attr_entries =
+                connection.query(format!("(matches \"{address}\" \"{attribute}\" ?)").parse()?)?;
+
+            for eae in existing_attr_entries {
+                let _ = connection.remove_object(eae.address()?)?;
+            }
+
+            let new_attr_entry = Entry {
+                entity: address,
+                attribute,
+                value: value.into_inner(),
+            };
+
+            connection.insert_entry(new_attr_entry)
+        })
+        .map_err(ErrorInternalServerError)?;
+
+    Ok(HttpResponse::Ok().json(new_address))
+}
+
 #[delete("/api/obj/{address_str}")]
 pub async fn delete_object(
     state: web::Data<State>,
@@ -365,11 +393,20 @@ pub async fn list_hier_roots(state: web::Data<State>) -> Result<HttpResponse, Er
     Ok(HttpResponse::Ok().json(result.as_hash().map_err(ErrorInternalServerError)?))
 }
 
+#[derive(Deserialize)]
+pub struct RescanRequest {
+    full: Option<String>,
+}
+
 #[post("/api/refresh")]
-pub async fn api_refresh(state: web::Data<State>) -> Result<HttpResponse, Error> {
+pub async fn api_refresh(
+    state: web::Data<State>,
+    web::Query(query): web::Query<RescanRequest>,
+) -> Result<HttpResponse, Error> {
     actix::spawn(crate::filesystem::rescan_vault(
         state.upend.clone(),
         state.job_container.clone(),
+        query.full.is_none(),
         false,
     ));
     Ok(HttpResponse::Ok().finish())
@@ -416,7 +453,7 @@ pub async fn get_info(state: web::Data<State>) -> Result<HttpResponse, Error> {
     Ok(HttpResponse::Ok().json(json!({
         "name": state.vault_name,
         "location": &*state.upend.vault_path,
-        "version": VERSION
+        "version": crate::common::PKG_VERSION
     })))
 }
 
