@@ -25,7 +25,7 @@ export default function (): HistorySource {
     },
     history: {
       get state() {
-        return history.location.state;
+        return history.location.state as object;
       },
       pushState(state, title, uri) {
         history.push(uri, state);
